@@ -788,6 +788,10 @@ ID要强调当下分解的多样性？因为走势本身就是当下形成中的
 19. 上下震荡是在所难免的，能否利用震荡来降低成本这也是一个分水岭。
 20. 不要对任何消息抱有过度的乐观和悲观，认真观察分析市场，市场走势会给出答案。
 21. 高开很容易就会把人的贪婪情绪调动起来。
+22. 买点买是有逻辑有规则买入，而追涨买则是基于情绪冲动性买入。
+23. 买点买卖点卖，看似简单，但如何找寻买卖点，找寻何级别买卖点，何级别买卖点参与
+    退出多少仓位，这其中大有文章，需要多看图识图并加以实践，毕竟走势图是无数资金
+    堆积出来的，是最昂贵的图画。 
 
 --摘自《即缠非缠》微博
 """,
@@ -824,6 +828,93 @@ ID要强调当下分解的多样性？因为走势本身就是当下形成中的
 
 --摘自《2007-04-27 08:42 教你炒股票50：操作中的一些细节问题》
 """,
+
+    "92": """
+思维上的关键，必须明确两点：
+
+一、买卖点操作后，等待是一个最关键的过程，必须密切关注相应的走势类型的生长与分类选择，这
+   一切都是当下的。
+
+二、买卖点本质上是走势类型的生长状况与分类决定的，反过来，某些买卖点的出现，又使得走势类
+   型的生长状况分类有一个明确的界定，这些都是观察市场细节的关键之处。
+
+--摘自《2007-04-12 15:39 教你炒股票45：持股与持币，两种最基本的操作》
+""",
+
+    "93": """
+注意，任何一次失误都要马上总结，不能连续失误再调整。如果真的出现连续失误，那就是你的方法
+有很大问题，必须改进，好好想好再操作。
+
+方法的问题无非几种：参与过小级别的操作、没有按买卖点操作、参照过于频繁、对图形判断不熟练、
+有盲点、乱听消息等等。先把问题找出来，究竟是什么问题。
+
+注意，失误的原因永远与市场无关，找原因，只能找自己的原因。
+
+--摘自《2007-03-09 11:51 教你炒股票35：给基础差的同学补补课》评论回复
+""",
+
+    "94": """
+走势只要没有出现中枢意义上的变动，都没什么值得一惊一乍的。
+
+--摘自《2007-03-13 09:00 教你炒股票36：走势类型连接结合性的简单运用》评论回复
+""",
+
+
+    "95": """
+网友问：我今天就一个股没坐稳，抛后大涨。心态浮躁，离市场太近未必是好事。 
+
+禅师答：不是离市场太近，而是离市场太远。何谓近？对市场的当下一目了然；何谓远？对市场走
+势毫无头绪，只会瞎蒙。当你知道市场在干什么，心自解脱，不会被市场的波动所迷惑。
+
+--摘自《2007-03-20 15:23 《论语》详解：给所有曲解孔子的人（58）》评论回复
+""",
+
+    "96": """
+网友问：博主禅心妙意,美哉!只是我等冥顽之辈,知易行难啦.可有验方? 
+
+禅师答：以此得失之心求之，永无出离之日。知且无知，行其无行，无知而妄知，无行而妄行，还
+求个验方、求个护身符干啥？可验方的，不离尔，离尔又求何验方？尔求尔之验方，骑驴找驴干啥？ 
+
+--摘自《2007-01-15 15:50 教你炒股票23：市场与人生》评论回复
+""",
+
+    "97": """
+市场的预测、观察、参与者，恰好又是市场走势的构成者，这就是市场预测的最基本起点。因此，
+市场的走势模式，归根结底就是市场预测、观察、参与者行为模式的同构，这意味着，唯一并绝对
+可以预测的，就是市场走势的基本形态。不学无术之辈，喜欢谈论所谓的点位，却不知道，点位只
+是基本形态演化的一个结果，是当下中形成了，形态是“不患”的，点位是“不患”之“患”，只要把
+握了这“不患”，其“患”自然就在当下的把握中。那种追求对点位的非当下把握，绝对是脑子进水，
+因为点位都是当下形成中的，这是一个“不患”，企图逃离这个“不患”而谋其“患”，不是脑子进水
+是什么？正因为点位都是在基本形态的演变中当下形成的“不患”，才有点位的“不患”之“患”。
+
+--摘自《2007-05-18 08:49 教你炒股票52：炒股票就是真正的学佛》
+""",
+
+
+    "98": """
+实际操作中，最基础的，就是对基本形态的最基本把握，这是“不患”的，只有立足于这“不患”上，
+才有对点位之“患”当下的把握。说白了，所有的操作练习，归根结底就是在此之上。所以，本ID说
+自己只是一个训练者，引导者，因为当下，只能是你的当下，离开你的操作当下，根本是不存在的。
+由此，不难理解另外一个操作上的“不患”，就是你事先确立的操作级别，这是“不患”的。
+
+市场，归根结底只是你的市场，就像，一个看花只能看到花的眼睛，那自然看花就是花，不会把花
+看成猴子，科学的把戏，就是要先假设所有的被科学定义为眼睛的物体，都只能把花看成花，所以
+科学在股市上注定死无葬身之地。
+
+--摘自《2007-05-18 08:49 教你炒股票52：炒股票就是真正的学佛》
+""",
+
+    "99": """
+市场的基本形态是什么，最基础的，就是反复说的以中枢、级别为基础的趋势与盘整。而背驰的级
+别一定不小于转折的级别，是市场预测的最基础手段。例如，你是一个30分钟级别的操作者，那么，
+任何30分钟级别下跌及30分钟级别以上的盘整，你都没必要参与。因此，当一个30分钟的顶背驰出
+现后，你当然就要绝对退出，为什么？因为这个退出是在一个绝对的预测基础上的，就是后面必然是
+一个30分钟级别下跌或扩展成30分钟级别以上的盘整，这就是最有用、最绝对的预测，这才是真正
+的预测，这是被本ID的理论绝对保证的，或者说这是被市场参与者的贪嗔痴疑慢所绝对保证的。
+
+--摘自《2007-05-18 08:49 教你炒股票52：炒股票就是真正的学佛》
+""",
+
 }
 
 
