@@ -51,6 +51,9 @@ class CzscAdvancedTrader:
         self.verbose = envs.get_verbose()
         self.kas = {freq: CZSC(b) for freq, b in bg.bars.items()}
 
+        # cache 是信号计算过程的缓存容器，需要信号计算函数自行维护
+        self.cache = OrderedDict()
+
         last_bar = self.kas[self.base_freq].bars_raw[-1]
         self.end_dt, self.bid, self.latest_price = last_bar.dt, last_bar.id, last_bar.close
         if self.get_signals:
@@ -59,9 +62,6 @@ class CzscAdvancedTrader:
         else:
             self.s = OrderedDict()
 
-        # cache 是信号计算过程的缓存容器，需要信号计算函数自行维护
-        self.cache = OrderedDict()
-
     def __repr__(self):
         return "<{} for {}>".format(self.name, self.symbol)
 
@@ -77,17 +77,18 @@ class CzscAdvancedTrader:
         for freq in self.freqs:
             ka: CZSC = self.kas[freq]
             bs = None
-            if freq == self.base_freq and self.long_pos:
-                # 在基础周期K线上加入最近的一些多头操作记录
+            if freq == self.base_freq:
+                # 在基础周期K线上加入最近的操作记录
                 bs = []
-                for op in self.long_pos.operates[-10:]:
-                    if op['dt'] < ka.bars_raw[0].dt:
-                        continue
+                if self.long_pos:
+                    for op in self.long_pos.operates[-10:]:
+                        if op['dt'] >= ka.bars_raw[0].dt:
+                            bs.append(op)
 
-                    if op['op'] in [Operate.LO, Operate.LA1, Operate.LA2]:
-                        bs.append({'dt': op['dt'], 'mark': "buy", 'price': op['price']})
-                    else:
-                        bs.append({'dt': op['dt'], 'mark': "sell", 'price': op['price']})
+                if self.short_pos:
+                    for op in self.short_pos.operates[-10:]:
+                        if op['dt'] >= ka.bars_raw[0].dt:
+                            bs.append(op)
 
             chart = ka.to_echarts(width, height, bs)
             tab.add(chart, freq)
